Sources
=======

.. automodule:: varlord.sources
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

Default Sources
---------------

.. automodule:: varlord.sources.defaults
   :members:

.. automodule:: varlord.sources.env
   :members:

.. automodule:: varlord.sources.cli
   :members:

.. automodule:: varlord.sources.dotenv
   :members:

Etcd Source
-----------

.. automodule:: varlord.sources.etcd
   :members:
   :special-members: __init__
   :exclude-members: _get_client, _model

